package FooBar;
use Function::Interface::Impl qw(IFoo IBar);

fun foo() :Return() { }
fun bar() :Return() { }

1;
